clear all;
close all;

%laws of nature
    g = 9.81;
    pa = 101325;            %Atmospheric pressure
    rho_c0 = 1.23;      
    rho_a = 1.23;
    gamma = 1.4;
    

%Hydrodynamic coefficients
%Added mass matrix
A=[0.74e5 0 0 0 0 0;
   0 0.735e5 0 -0.251e5 0 -0.114e6;
   0 0 0.273e5 0 -0.168e3 0;
   0 -0.251e5 0 0.496e6 0 0.964e5;
   0 0 -0.168e3 0 0.774e6 0 ;
   0 -0.114e6 0 0.964e5 0 0.288e7];

%Linear Damping 
D=[0.132e4 0 0 0 0 0;
   0 0.132e4 0 0.194e4 0 0.417e5;
   0 0 0.192e5 0 -0.145e5 0;
   0 0.194e4 0 0.381e6 0 -0.149e5;
   0 0 0.128e5 0 0.548e6 0;
   0 -0.344e5 0 0.11e5 0 0.642e5];


%Restoring
C=[0 0 0 0 0 0;
   0 0 0 0 0 0;
   0 0 330000 0 251000 0;
   0 0 0 6440000 0 0;
   0 0 251000 0 10500000 0;
   0 0 0 0 0 0]; 

%Mass matrix
M=[92000 0 0 0 0 0;
   0 92000 0 0 0 0;
   0 0 92000 0 0 0;
   0 0 0 9200000 0 0;
   0 0 0 0 57600000 0;
   0 0 0 0 0 57600000]; 
   



%Various parameters
    Ac = 160;               %Lift area of cushion (20*8)
    h0 = 3.3;               %Equilibrium distance from cushion 'ceiling' to free water surface
    p0 = 2400;              %Equilibrium'over-pressure
    cn          = 0.61;              %Orrifice coefficient, Blir ganga inn med Kp uansety
    K1          = 1/(gamma*(1+(pa/p0)));
    K2          = 0.51575*cn;               %Closely related to the total leakage area from the seals, but also used for tuning as this area is hard to determine
    L           = 20;
    x_cp        = 0.7;                  % Distance from COG to centre of pressure
    Bias        = 2.5;               %Valve vent louver Bias
    Aw          = 22*2*0.9;         %waterline area. "Endret"
    l_x_vv      = 12.5;
    l_y_wj_sb   = 5;
    l_y_wj_p    =-5;
    l_x_wj_sb   =-12.5;
    l_x_wj_p    =-12.5;
    etta_0      =[0;0;0];
    nu_0        =[0;0;0;0;0;0;0;0;0;0;0;0;0];

%Kinetic tools    
    O=zeros(6);
    I=eye(6);
    MA=(M+A);
    C_ma=MA\C;
    
    %Linearized Dynamics
    A_dyn = [O I;
             -C_ma -D_ma];    

%Pressure-Vessel effect
H=[0;
   0;
   0;
   0;
   0;
   0;
   0;
   0;
   Ac*p0/(M(3,3)+A(3,3));
   0;
   x_cp*Ac*p0/(M(5,5)+A(5,5));
   0];

%Inverse fan characteristics polynomial coefficients
   p1 = -1.3062e-06;
   p2 = -0.003076;
   p3 = 129.83;
   
%Thrust Configuration Matrix
T = [0 1 ol0 1 0;
     1 0 1 0 1;
     0 0 0 0 0;
     0 0 0 0 0;
     0 0 0 0 0;
     l_x_vv -l_y_wj_p l_x_wj_p -l_y_wj_sb l_x_wj_sb]; %Thrust Configuration Matrix
%Input Matrix
B_dyn = [1/(M(1,1)+A(1,1)) 0 0 0 0 0;
    0 1/(M(2,2)+A(2,2)) 0 0 0 0;
    0 0 1/(M(3,3)+A(3,3)) 0 0 0;
    0 0 0 1/(M(4,4)+A(4,4)) 0 0;
    0 0 0 0 1/(M(5,5)+A(5,5)) 0;
    0 0 0 0 0 1/(M(6,6)+A(6,6))];

etta_ref=[10;10;0];


